@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.102_03';
+our $VERSION = '0.103_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Aug 16 15:09:04 2018 GMT
+# on Tue Aug 21 14:16:39 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1699,7 +1699,7 @@ __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
 __PACKAGE__->status( add => 24869, iridium => 'S', 'Iridium 15', '' );
 __PACKAGE__->status( add => 24870, iridium => '-', 'Iridium 17', 'Tumbling' );
 __PACKAGE__->status( add => 24871, iridium => '-', 'Iridium 920', 'Tumbling' );
-__PACKAGE__->status( add => 24872, iridium => '-', 'Iridium 18', 'Tumbling' );
+__PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-08-19' );
 __PACKAGE__->status( add => 24873, iridium => '-', 'Iridium 921', 'Tumbling' );
 __PACKAGE__->status( add => 24903, iridium => '-', 'Iridium 26', 'Tumbling' );
 __PACKAGE__->status( add => 24904, iridium => 'D', 'Iridium 25', 'Decayed 2018-05-14' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 # Summary:
 # Operational [+]: 17
 #       Spare [S]: 13
-#    Tumbling [-]: 38
-#     Decayed [D]: 29
+#    Tumbling [-]: 37
+#     Decayed [D]: 30
 
 1;
 
